http

package
v0.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 10, 2025 License: MIT Imports: 6 Imported by: 1

Documentation

Overview

Package http includes handlers and utilties

Index

Constants

This section is empty.

Variables

var ErrNilCert = errors.New("nil cert")

Functions

func ClientWithCert added in v0.9.0

func ClientWithCert(client *http.Client, cert *tls.Certificate) (*http.Client, error)

ClientWithCert injects cert for mTLS into a copy of client. Transports and TLS configs are created (if nil) or cloned as needed. If client is nil the default HTTP client will be used.

func ReadAllAndReplaceBody

func ReadAllAndReplaceBody(r *http.Request) ([]byte, error)

ReadAllAndReplaceBody reads all of r.Body and replaces it with a new byte buffer.

Types

This section is empty.

Directories

Path Synopsis
Package authproxy is a simple reverse proxy for Apple MDM clients.
Package authproxy is a simple reverse proxy for Apple MDM clients.

Jump to