test

package
v0.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 10, 2025 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GenerateRandomCertificateSerialNumber

func GenerateRandomCertificateSerialNumber() (*big.Int, error)

func PlistReader

func PlistReader(v interface{}) (io.Reader, error)

PlistReader encodes v to XML Plist.

func SelfSignedCertRSAResigner added in v0.8.0

func SelfSignedCertRSAResigner(tmpl *x509.Certificate) (key *rsa.PrivateKey, cert *x509.Certificate, err error)

func SimpleSelfSignedRSAKeypair

func SimpleSelfSignedRSAKeypair(cn string, days int) (key *rsa.PrivateKey, cert *x509.Certificate, err error)

Types

This section is empty.

Directories

Path Synopsis
Package protocol implements primitives and interfaces of the base Apple MDM protocol.
Package protocol implements primitives and interfaces of the base Apple MDM protocol.

Jump to