Documentation
¶
Index ¶
- func GenerateRandomCertificateSerialNumber() (*big.Int, error)
- func PlistReader(v interface{}) (io.Reader, error)
- func SelfSignedCertRSAResigner(tmpl *x509.Certificate) (key *rsa.PrivateKey, cert *x509.Certificate, err error)
- func SimpleSelfSignedRSAKeypair(cn string, days int) (key *rsa.PrivateKey, cert *x509.Certificate, err error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PlistReader ¶
PlistReader encodes v to XML Plist.
func SelfSignedCertRSAResigner ¶ added in v0.8.0
func SelfSignedCertRSAResigner(tmpl *x509.Certificate) (key *rsa.PrivateKey, cert *x509.Certificate, err error)
func SimpleSelfSignedRSAKeypair ¶
func SimpleSelfSignedRSAKeypair(cn string, days int) (key *rsa.PrivateKey, cert *x509.Certificate, err error)
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package protocol implements primitives and interfaces of the base Apple MDM protocol.
|
Package protocol implements primitives and interfaces of the base Apple MDM protocol. |
Click to show internal directories.
Click to hide internal directories.